@@ -1,18 +1,18 @@
 // crossbox.h
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef CROSSBOX_H
 #define CROSSBOX_H
 
-#include <qchkbox.h>
+#include <qcheckbox.h>
 #include <qpainter.h>
 
 class CrossBox : public QCheckBox
 {
 public:
-    CrossBox(const char *text, QWidget *parent, const char *name = 0);
+    CrossBox(const char *text, QWidget *parent);
 
 protected:
     virtual void drawButton(QPainter *paint);
