@@ -1,13 +1,13 @@
 // fieldsel.h				emacs, this is written in -*-c++-*-
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef FIELDSEL_H
 #define FIELDSEL_H
 
 #include <qdialog.h>
-#include <qbitarry.h>
+#include <qbitarray.h>
 #include "crossbox.h"
 #include "proc.h"
 
