@@ -1,15 +1,15 @@
 // prefs.h				emacs, this is written in -*-c++-*-
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef PREFS_H
 #define PREFS_H
 
 #include <qdialog.h>
-#include <qradiobt.h>
+#include <qradiobutton.h>
 #include <qlabel.h>
-#include <qbttngrp.h>
+#include <qbuttongroup.h>
 #include "crossbox.h"
 
 class Preferences : public QDialog {
