@@ -6,12 +6,14 @@
 #ifndef PROC_H
 #define PROC_H
 
+
 #include "config.h"
 
 #include <unistd.h>
 #include <sys/time.h>
 
 #ifdef SOLARIS
+#include <inttypes.h>
 #include <procfs.h>
 #include <kstat.h>
 #endif
@@ -31,6 +33,13 @@ enum fields {
     F_PID, F_PPID, F_PGID, F_SID, F_TTY,
 #ifdef LINUX
     F_TPGID,
+#endif
+#ifdef MOSIX
+    F_MIGR,
+    F_LOCKED,
+    F_NMIGS,
+    F_NOMOVE,
+    F_RPID,
 #endif
     F_USER, F_GROUP,
     F_UID, F_EUID,
@@ -164,6 +173,10 @@ public:
     bool read_fds();
     bool read_maps();
     bool read_environ();
+#ifdef MOSIX
+    static void check_for_mosix();
+    static Svec<int> mosix_nodes();
+#endif
 #ifdef LINUX
     static bool read_socket_list(Sockinfo::proto_t proto, char *pseudofile);
     static void read_sockets();
@@ -321,6 +334,19 @@ public:
     static int page_k_shift;	// log2(pagesize / 1024)
 
     char refcnt;
+
+#ifdef MOSIX
+    bool isremote;
+    int from;
+    int where;
+    int remotepid;
+    QString migr; // String explaining migration "node>" or ">node" 
+    int nmigs;
+    int locked;
+    QString cantmove;
+
+    static bool mosix_running;	// true if MOSIX is running
+#endif
 };
 
 class Category
@@ -568,7 +594,11 @@ public:
     static int user_fields[];
     static int jobs_fields[];
     static int mem_fields[];
-
+#ifdef MOSIX
+    static int user_fields_mosix[];
+    static int jobs_fields_mosix[];
+    static int mem_fields_mosix[];
+#endif
     static float avg_factor;		// exponential factor for averaging
 
     static const int cpu_avg_time = 30 * 1000;	// averaging time for WCPU (ms)
