@@ -99,8 +99,12 @@ public:
     static bool tree_gadgets;		// use open/close gadgets (triangles)
     static bool tree_lines;		// draw tree branch lines
 
-    static Svec<Command *> *commands;
+    static bool comm_is_magic;		// auto-remove COMM when switching
+    					// to linear mode (automatically set
+					// when COMM is auto-inserted)
 
+    static Svec<Command *> *commands;
+    
     // colors which may be set by the user
     enum {
 	COLOR_CPU_USER,
@@ -121,13 +125,30 @@ public:
 
     static QColor color_set[NUM_COLORS];
 
+    enum menuid {
+	MENU_SIGQUIT, MENU_SIGILL, MENU_SIGABRT, MENU_SIGFPE, MENU_SIGSEGV,
+	MENU_SIGPIPE, MENU_SIGALRM, MENU_SIGUSR1, MENU_SIGUSR2, MENU_SIGCHLD,
+	MENU_SIGCONT, MENU_SIGSTOP, MENU_SIGTSTP, MENU_SIGTTIN, MENU_SIGTTOU,
+	MENU_RENICE, MENU_SCHED,
+	MENU_DETAILS,
+	MENU_PARENT, MENU_CHILD, MENU_DYNASTY,
+	MENU_SIGTERM, MENU_SIGHUP, MENU_SIGINT, MENU_SIGKILL, MENU_OTHERS,
+	MENU_PROCS, MENU_FIELDS, MENU_CUSTOM,
+        MENU_PATH, MENU_INFOBAR, MENU_CTRLBAR, MENU_CUMUL, MENU_PREFS,
+#ifdef MOSIX
+	POPUP_MIGRATE,
+#endif
+	MENU_FIRST_COMMAND	// must be last
+    };
+
 public slots:
     // menu:
     void sig_term();
     void sig_hup();
-    void sig_int();
+    void sig_stop();
+    void sig_cont();
     void sig_kill();
-    void other_menu(int id);
+    void signal_menu(int id);
     void about();
     void license();
     void menu_update();
@@ -144,6 +165,7 @@ public slots:
     void menu_children();
     void menu_dynasty();
     void menu_custom();
+    void mig_menu(int id);	// MOSIX only
     void menu_edit_cmd();
     void make_command_menu();
     void run_command(int id);
@@ -160,6 +182,7 @@ public slots:
     void field_added(int index);
     void field_removed(int index);
     void table_mode(bool treemode);
+    void col_reorder(int, int);
 
     void details_closed(Details *d);
     void open_details(int row);
@@ -184,9 +207,15 @@ protected:
     void transfer_selection();
     void update_table(int update_col);
     void update_menu_selection_status();
+    void adjust_popup_menu(QPopupMenu *m, bool cont);
+    bool all_selected_stopped();
 
     void locate_relatives(int Procinfo::*a, int Procinfo::*b);
     QPopupMenu *make_signal_menu();
+#ifdef MOSIX
+    QPopupMenu *make_migrate_menu();
+    void migrate_selected(int sig);
+#endif
     void send_to_selected(int sig);
     void sendsig(Procinfo *p, int sig);
     void earlier_refresh();
@@ -220,7 +249,7 @@ private:
     FieldSelect *field_win;
     Preferences *prefs_win;
     CommandDialog *command_win;
-
+    
     QList<Details> details;
 
     int update_period;				// in ms
@@ -237,24 +266,9 @@ private:
 
     int context_col;		// where heading context menu was clicked
 
-    enum menuid {
-	MENU_SIGQUIT, MENU_SIGILL, MENU_SIGABRT, MENU_SIGFPE, MENU_SIGSEGV,
-	MENU_SIGPIPE, MENU_SIGALRM, MENU_SIGUSR1, MENU_SIGUSR2, MENU_SIGCHLD,
-	MENU_SIGCONT, MENU_SIGSTOP, MENU_SIGTSTP, MENU_SIGTTIN, MENU_SIGTTOU,
-	MENU_RENICE, MENU_SCHED,
-	MENU_DETAILS,
-	MENU_PARENT, MENU_CHILD, MENU_DYNASTY,
-	MENU_SIGTERM, MENU_SIGHUP, MENU_SIGINT, MENU_SIGKILL, MENU_OTHERS,
-	MENU_PROCS, MENU_FIELDS, MENU_CUSTOM,
-        MENU_PATH, MENU_INFOBAR, MENU_CTRLBAR, MENU_CUMUL, MENU_PREFS,
-	MENU_FIRST_COMMAND	// must be last
-    };
-
     static const char *color_name[NUM_COLORS];
 };
 
-
-
 #endif // QPS_H
 
 
