@@ -1,16 +1,16 @@
 // scheddlg.h
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef SCHEDDLG_H
 #define SCHEDDLG_H
 
 #include <qdialog.h>
-#include <qradiobt.h>
+#include <qradiobutton.h>
 #include <qlabel.h>
-#include <qlined.h>
-#include <qbttngrp.h>
+#include <qlineedit.h>
+#include <qbuttongroup.h>
 
 class SchedDialog : public QDialog {
     Q_OBJECT
