@@ -1,7 +1,7 @@
 // wchan.h
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef WCHAN_H
 #define WCHAN_H
@@ -13,6 +13,7 @@ class Wchan {
 public:
     static QString name(unsigned addr);
 
+#ifdef LINUX
 private:
     static bool open_sysmap();
     static bool try_sysmap(const char *path);
@@ -23,6 +24,7 @@ private:
     static char *sysmap;	// pointer to mmap()ed System.map
     static bool sysmap_inited;	// if an attempt to read sysmap has been made
     static int sysmap_size;
+#endif
 };
 
 #endif	// WCHAN_H
